@@ -1,7 +1,7 @@
 #  addAlgorithm.R
 #  FBA and friends with R.
 #
-#  Copyright (C) 2010-2012 Gabriel Gelius-Dietrich, Dpt. for Bioinformatics,
+#  Copyright (C) 2010-2013 Gabriel Gelius-Dietrich, Dpt. for Bioinformatics,
 #  Institute for Informatics, Heinrich-Heine-University, Duesseldorf, Germany.
 #  All right reserved.
 #  Email: geliudie@uni-duesseldorf.de
@@ -28,19 +28,19 @@
 #
 #
 
-addAlgorithm <- function(alg, fkt = "optimizer") {
+addAlgorithm <- function(alg, purpose) {
   
     stopifnot(inherits(alg, "character"),
-              inherits(fkt, "character"),
+              inherits(purpose, "character"),
               (length(alg) == 1),
-              (length(fkt) == 1))
+              (length(purpose) == 1))
 
 
-    if (alg %in% .SYBILenv$algorithm[[fkt]]) {
+    if (alg %in% .SYBILenv$algorithm[[purpose]]) {
         stop("algorithm ", sQuote(alg), " already exists")
     }
     else {
-        .SYBILenv$algorithm[[fkt]] <- append(.SYBILenv$algorithm[[fkt]], alg)
+        .SYBILenv$algorithm[[purpose]] <- append(.SYBILenv$algorithm[[purpose]], alg)
     }
         
     return(invisible(NULL))
