@@ -1,7 +1,7 @@
 #  checkAlgorithm.R
 #  FBA and friends with R.
 #
-#  Copyright (C) 2010-2012 Gabriel Gelius-Dietrich, Dpt. for Bioinformatics,
+#  Copyright (C) 2010-2013 Gabriel Gelius-Dietrich, Dpt. for Bioinformatics,
 #  Institute for Informatics, Heinrich-Heine-University, Duesseldorf, Germany.
 #  All right reserved.
 #  Email: geliudie@uni-duesseldorf.de
@@ -28,9 +28,9 @@
 #
 #
 
-checkAlgorithm <- function(alg, fkt = "optimizer") {
+checkAlgorithm <- function(alg, purpose) {
   
-    return(alg %in% .SYBILenv$algorithm[[fkt]])
+    return(alg %in% .SYBILenv$algorithm[[purpose]])
 
 }
 
